# Generated by Django 2.0.2 on 2018-06-01 14:14

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ChartConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('model_name', models.CharField(blank=True, help_text="The name of the model class you's like to analyse.", max_length=255)),
                ('label', models.CharField(blank=True, help_text='A label of the chart.', max_length=255)),
                ('field_path', models.CharField(blank=True, help_text='The constructor of to the plotted value.', max_length=255)),
                ('help_text', models.CharField(blank=True, help_text='Contains a description of the chart', max_length=255)),
                ('legend_x', models.CharField(blank=True, help_text='Text for the legend of the x-axis', max_length=255)),
                ('legend_y', models.CharField(blank=True, help_text='Text for the legend of the y-axis', max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='ChartType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, help_text='A name of the chart type.', max_length=255)),
                ('icon', models.CharField(blank=True, help_text='A HTML snippet which could be used to display a link to the chart', max_length=255)),
            ],
        ),
        migrations.AddField(
            model_name='chartconfig',
            name='chart_types',
            field=models.ManyToManyField(blank=True, help_text='A selection of chart types which should be accessible.', to='charts.ChartType'),
        ),
    ]
